@@ -334,7 +334,9 @@ class Job:
         if self._volumes:
             for vol in self._volumes:
                 if vol.persistent_volume_claim:
-                    if not self.workspace_vc or self.workspace_vc.shared and vol.persistent_volume_claim.claim_name == self.workspace_vc.name:
+                    if self.workspace_vc and self.workspace_vc.shared and vol.persistent_volume_claim.claim_name == self.workspace_vc.name:
+                        continue
+                    else:
                         response = api_request(core_api.delete_namespaced_persistent_volume_claim,
                                                 namespace=self.namespace,
                                                 name=vol.persistent_volume_claim.claim_name)
